package com.me.common.ecs;

import com.badlogic.gdx.utils.Array;

public abstract class EntitySystem {

    private long typeBits;

    protected Array<Entity> entities;

    public EntitySystem(Class<? extends Component>... components) {
        typeBits = ComponentType.getMaskBits(components);
        entities = new Array<>();
    }

    public void preProcessing() {}

    public Array<Entity> getEntities() {
        return entities;
    }

    public void processEntities(float dt) {
        for (int i = 0, n = getEntities().size; i < n; i++) {
            processEntity(entities.get(i), dt);
        }
    }

    public abstract void processEntity(Entity entity, float dt);

    public void postProcessing() {}

    public boolean interestedIn(Entity entity) {
        return (entity.getComponentBits() & typeBits) == typeBits;
    }

}
